@@ -131,7 +131,7 @@ class Crawler:  # pylint: disable=too-many-public-methods
             raise CrawlerError(message)
         self.__browser = browser
         self.__driver = None
-        self.__options = Noneexecutable_path="."
+        self.__options = None
         self.__logger = log(self.__class__.__name__)
         self.timeout = 50
         self.quit_on_failure = quit_on_failure
